import java.io.*;
import java.net.*;
import java.util.*;
import sv.data.*;
import sv.engine.SV2Protocol;

public class readSV2File {

  public static void main(String[] args) {
    String host = "rhodeisland";
    int port = 7653;       

    String filename = " ";
    Socket sock = null;
    DataOutputStream out = null;
    DataInputStream in = null;

    try {
       BufferedReader reader = 
              new BufferedReader(new InputStreamReader(System.in));    

       System.out.print("Enter the file name: ");
       filename = reader.readLine().trim();
       reader.close();

       System.out.println("Reading: " + filename);

       in = new DataInputStream(new BufferedInputStream(
                                   new FileInputStream(filename)));
       
       DataSetBrief brief = null;

       int noOfDataSet = in.readInt();   
       for (int i=0; i<noOfDataSet; i++) {
         int sz = in.readInt();
         byte[] byteArr = new byte[sz];
         in.read(byteArr, 0, sz);
         String title = new String(byteArr);

         sz = in.readInt();
         TimeData[] tds = new TimeData[sz];
         int rank = 0;

         for (int j=0; j<sz; j++) {
           // read magine number
           int magic = in.readInt();
           switch (magic) {
             case 101:
               rank = TimeData.ONED;
               tds[j] = DataReader.parse101(in);
               break;
             case 201:
               rank = TimeData.TWOD;
               tds[j] = DataReader.parse201(in);
               break;
             default:
               System.out.println("This is not SV2 file.");
               return;
           }
         }
      
         DataSet dataSet = new DataSet(tds);
         dataSet.setDataName(title);
      
         if (brief  == null)
           brief = new DataSetBrief(title, 1, rank, dataSet.getDataSize());
 
         brief.addDataSet(dataSet);
       }

       in.readByte();               // dummy read
       brief.updateInfo();

       //////////////////////////////////////////////////////////////////
       // now send it
       /////////////////////////////////////////////////////////////////
       DataSet[] dataSets = brief.getDataSet();

       for (int i=0; i<dataSets.length; i++) {
         sock = new Socket(host, port);
         out = new DataOutputStream(sock.getOutputStream());
         out.writeInt(SV2Protocol.RAW_DATA_FEED);   

         String name = dataSets[i].getDataName();
         byte[] byteArr = name.getBytes();
         out.writeInt(byteArr.length);
         out.write(byteArr, 0, byteArr.length);

         int sz = dataSets[i].getNoOfTimes();
         out.writeInt(sz);

         for (int j=0; j<sz; j++) 
           dataSets[i].getTimeData(j).sendingData(out);

         out.writeInt(0);
       }

       in.close();
       out.close();
       sock.close();

    } catch (Exception e) {
      e.printStackTrace();
      System.exit(1);
    }
  }

} // end of class





